==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/index.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once 'init_processor.php';
if ($_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
//session_regenerate_id(TRUE);
?>
<?php
//echo ini_get("include_path");
if (isset($_GET['image']) && $_GET['image'] == 'on') {
  $get_image = 'on';
} else {
  $get_image = 'off';
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$site_name} {$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
</head>
<body>
<div id="header">
<?php
echo "<h1 id=\"index-head\" class=\"head1\">{$site_name}</h1>\n";
echo "<p class=\"caption\">by <abbr title=\"{$product_name_full}\">{$product_name_abbr}</abbr> Ver.{$product_version}</p>\n";
?>
</div>
<div id="index-contents" class="contents">
<div class="index-content content">
<h2 id="entries-index-head">みんなのページ</h2>
<ul>
<li><a href="./entries.php<?php if($_GET['image'] == 'on') echo '?image=on'; ?>" class="entries">みんなのエントリー</a></li>
<li><a href="./entries.php?album=public<?php if($_GET['image'] == 'on') echo '&amp;image=on'; ?>" class="entries">みんなのアルバム</a></li>
<li><a href="./entries.php?users=public<?php if($_GET['image'] == 'on') echo '&amp;image=on'; ?>" class="entries">ユーザー一覧</a></li>
</ul>
</div>

<div class="index-content">
<h2 id="users-index-head">ユーザーのページ</h2>
<ul>
<?php
if ($_SESSION['auth'] === TRUE){
  echo "<li><a href=\"./entries.php?user={$_SESSION['hatenaid']}";
  if ($_GET['image'] == 'on') echo '&amp;image=on';
  echo "\" class=\"user\">{$_SESSION['hatenaid']} のエントリー</a></li>\n";
  echo "<li><a href=\"./entries.php?following={$_SESSION['hatenaid']}\n";
  if ($_GET['image'] == 'on') echo '&amp;image=on';
  echo "\" class=\"user\">{$_SESSION['hatenaid']} のアンテナ</a></li>\n";
  echo "<li><a href=\"./entries.php?favours={$_SESSION['hatenaid']}";
  if ($get_image == 'on') echo "&amp;image=on";
  echo "\" class=\"user\">{$_SESSION['hatenaid']} のお気に入り</a></li>\n";
  echo '<li><a href="./login.php?log=out" class="user">ログアウト</a></li>'."\n";
} else {
  echo '<li><form method="get" action="./entries.php">';
  echo '<label for="username">id:</label><input type="text" name="user" maxlength="32" id="username"/><label for="username">のエントリーを</label><input type="submit" value="表示" />';
  if ($_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />';
  echo '</form></li>'."\n";
  echo '<li><form method="get" action="./entries.php">';
  echo '<label for="userflw">id:</label><input type="text" name="following" maxlength="32" id="userflw"/><label for="userflw">のアンテナを</label><input type="submit" value="表示" />';
  if ($_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />';
  echo '</form></li>'."\n";
  echo '<li><a href="./login.php';
  if ($_GET['image'] == 'on') echo '?image=on';
  echo '" class="user">ログイン</a></li>'."\n";
}
?>
</ul>
</div>

<div class="index-content">
<h2 id="keywords-index-head">キーワード</h2>
<ul>
<li><form method="get" action="./keywords.php" accept-charset="UTF-8">
<label for="go2keyword">キーワード</label><input type="text" name="word" maxlength="170" id="go2keyword" /><label for="go2keyword">を</label>
<input type="submit" value="検索" />
<?php if ($_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />'; ?>
</form></li>
<?php
$request_url = "{$api_base_url}keywords/hot.xml".'?without_related_keywords=1';
// $use_cache = FALSE;
require_once 'keywords_processor.php';
?>
<?php
if ($_SESSION['auth'] === TRUE){
	echo '<li><a href="./keywords.php?user=' . $_SESSION['hatenaid'];
	echo '" class="keyword">' . $_SESSION['hatenaid'] . ' のお気に入りキーワード</a></li>' . "\n";
}
?>
<li><a href="./keywords.php<?php if($_GET['image'] == 'on') echo '?image=on'; ?>" class="keyword">キーワード一覧</a></li>
</ul>
</div>
</div>
<hr />
<?php echo $footer; ?>
</body>
</html>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/index.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once 'init_processor.php';
if (!isset($_SESSION['auth']) || $_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
//session_regenerate_id(TRUE);
?>
<?php
//echo ini_get("include_path");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$site_name} {$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
</head>
<body>
<div id="header">
<?php
echo "<h1 id=\"index-head\" class=\"head1\">{$site_name}</h1>\n";
echo "<p class=\"caption\">by <abbr title=\"{$product_name_full}\">{$product_name_abbr}</abbr> Ver.{$product_version}</p>\n";
?>
</div>
<div id="index-contents" class="contents">
<div class="index-content content">
<h2 id="entries-index-head">みんなのページ</h2>
<ul>
<li><a href="./entries.php<?php if(isset($_GET['image']) && $_GET['image'] == 'on') echo '?image=on'; ?>" class="entries">みんなのエントリー</a></li>
<li><a href="./entries.php?album=public<?php if(isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on'; ?>" class="entries">みんなのアルバム</a></li>
<li><a href="./entries.php?users=public<?php if(isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on'; ?>" class="entries">ユーザー一覧</a></li>
</ul>
</div>

<div class="index-content">
<h2 id="users-index-head">ユーザーのページ</h2>
<ul>
<?php
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
  echo "<li><a href=\"./entries.php?user={$_SESSION['hatenaid']}";
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
  echo "\" class=\"user\">{$_SESSION['hatenaid']} のエントリー</a></li>\n";
  echo "<li><a href=\"./entries.php?following={$_SESSION['hatenaid']}\n";
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
  echo "\" class=\"user\">{$_SESSION['hatenaid']} のアンテナ</a></li>\n";
  echo "<li><a href=\"./entries.php?favours={$_SESSION['hatenaid']}";
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo "&amp;image=on";
  echo "\" class=\"user\">{$_SESSION['hatenaid']} のお気に入り</a></li>\n";
  echo '<li><a href="./login.php?log=out" class="user">ログアウト</a></li>'."\n";
} else {
  echo '<li><form method="get" action="./entries.php">';
  echo '<label for="username">id:</label><input type="text" name="user" maxlength="32" id="username"/><label for="username">のエントリーを</label><input type="submit" value="表示" />';
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />';
  echo '</form></li>'."\n";
  echo '<li><form method="get" action="./entries.php">';
  echo '<label for="userflw">id:</label><input type="text" name="following" maxlength="32" id="userflw"/><label for="userflw">のアンテナを</label><input type="submit" value="表示" />';
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />';
  echo '</form></li>'."\n";
  echo '<li><a href="./login.php';
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '?image=on';
  echo '" class="user">ログイン</a></li>'."\n";
}
?>
</ul>
</div>

<div class="index-content">
<h2 id="keywords-index-head">キーワード</h2>
<ul>
<li><form method="get" action="./keywords.php" accept-charset="UTF-8">
<label for="go2keyword">キーワード</label><input type="text" name="word" maxlength="170" id="go2keyword" /><label for="go2keyword">を</label>
<input type="submit" value="検索" />
<?php if (isset($_GET['image']) && $_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />'; ?>
</form></li>
<?php
$request_url = "{$api_base_url}keywords/hot.xml".'?without_related_keywords=1';
// $use_cache = FALSE;
require_once 'keywords_processor.php';
?>
<?php
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
	echo '<li><a href="./keywords.php?user=' . $_SESSION['hatenaid'];
	echo '" class="keyword">' . $_SESSION['hatenaid'] . ' のお気に入りキーワード</a></li>' . "\n";
}
?>
<li><a href="./keywords.php<?php if(isset($_GET['image']) && $_GET['image'] == 'on') echo '?image=on'; ?>" class="keyword">キーワード一覧</a></li>
</ul>
</div>
</div>
<hr />
<?php echo $footer; ?>
</body>
</html>
